@@ -1,6 +1,11 @@
+import os
+os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
+
 from mandaw.main import Mandaw
 from mandaw.gameobject import GameObject
 from mandaw.line import Line
 from mandaw.color import Color
 from mandaw.sprite import Sprite
 from mandaw.text import Text
+from mandaw.input import Controls
+from mandaw.audio import Audio
